@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2012 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2012 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -51,15 +51,15 @@ struct GNUNET_Mutex *
 GNUNET_mutex_create (int isRecursive);
 
 
-void 
+void
 GNUNET_mutex_destroy (struct GNUNET_Mutex *mutex);
 
 
-void 
+void
 GNUNET_mutex_lock (struct GNUNET_Mutex *mutex);
 
 
-void 
+void
 GNUNET_mutex_unlock (struct GNUNET_Mutex *mutex);
 
 
